======
adnipy
======


Process ADNI study data with adnipy.


Adnipy is a python package designed for working with the `ADNI database`_.
It also offers some handy tools for file operations.

* Free software: MIT license
* Documentation: https://adnipy.readthedocs.io


Credits
-------

This package was created with Cookiecutter_ and the
`audreyr/cookiecutter-pypackage`_ project template.

.. _Cookiecutter: https://github.com/audreyr/cookiecutter
.. _`audreyr/cookiecutter-pypackage`: https://github.com/audreyr/cookiecutter-pypackage
.. _`ADNI database`: http://adni.loni.usc.edu/
